@@ -15,6 +15,8 @@ import json
 import os
 from polly.help import example
 from polly.tracking import Track
+from datetime import datetime
+import math
 
 
 class Workspaces:
@@ -22,8 +24,10 @@ class Workspaces:
     This class contains functions to interact with workspaces on Polly. Users can create a workspace, fetch list\
  of workspaces, upload data to workspace and download data from workspace. To get started, users need to \
 initialize a object that can use all function and methods of Workspaces class.
+
     Args:
         token (str): Authentication token from polly
+
     Usage:
         from polly.workspaces import Workspaces
 
@@ -39,9 +43,10 @@ initialize a object that can use all function and methods of Workspaces class.
             const.COMPUTE_ENV_VARIABLE, default_env, env
         )
         self.session = Polly.get_session(token, env=env)
-        self.base_url = f"https://v2.api.{self.session.env}.elucidata.io"
+        self.base_url = f"https://apis.{self.session.env}.elucidata.io/mithoo"
         self.base_url_auth = f"https://apis.{self.session.env}.elucidata.io/auth"
         self.resource_url = f"{self.base_url}/workspaces"
+        self.resource_url_search = f"{self.base_url}/_search"
         if self.session.env == "polly":
             self.env_string = "prod"
         elif self.session.env == "testpolly":
@@ -54,7 +59,7 @@ initialize a object that can use all function and methods of Workspaces class.
         """
         This function create workspace on Polly.
         Returns a Dictionary object like this
-                        {
+                        ``{
                         'id': 9999,
                         'name': 'rrrrr',
                         'active': True,
@@ -67,7 +72,8 @@ initialize a object that can use all function and methods of Workspaces class.
                             'labels': ''
                         },
                         'organisation': 1
-                        }
+                        }``
+
         Args:
               name (str): name of the workspace
               description (str, optional): general information about workspace
@@ -96,10 +102,12 @@ initialize a object that can use all function and methods of Workspaces class.
     def fetch_my_workspaces(self):
         """
         This function fetch workspaces from Polly.
+
         Args:
-              None
+              None: None
+
         Returns:
-              A table with workspace specific attributes
+              Table: A table with workspace specific attributes
         """
         all_details = self._fetch_workspaces_iteratively()
         pd.set_option("display.max_columns", 20)
@@ -118,93 +126,184 @@ initialize a object that can use all function and methods of Workspaces class.
         """
         Fetch all workspaces iteratively by making api calls until links is None.
         """
-        url = self.resource_url
+        url = self.resource_url_search
         all_details = []
+        from_index = 0
+        size = 20
         while True:
-            response = self.session.get(url)
+            payload = {
+                "from": from_index,
+                "size": size,
+                "sort": [{"created_date": {"order": "desc"}}],
+                "query": {
+                    "nested": {
+                        "path": "permissions",
+                        "query": {"match": {"permissions.user_id": "{user_id}"}},
+                    }
+                },
+            }
+            response = self.session.post(url, data=json.dumps(payload))
             error_handler(response)
-            data = response.json()["data"]
+            data = response.json()["hits"]["hits"]
+            total_hits = response.json()["hits"]["total"]["value"]
             for workspace_details in data:
-                self._modify_data(workspace_details)
-                all_details.append(workspace_details.get("attributes"))
-            links = response.json().get("links").get("next")
-            if links is None:
+                modified_workspace_details = self._modify_data(workspace_details)
+                all_details.append(modified_workspace_details)
+            from_index += size
+            if from_index >= total_hits:
                 break
-            url = f"{self.base_url}{links}"
         return all_details
 
     def _modify_data(self, data):
         """
         Removing less informative fields and making information user friendly
         """
-        data_dict = data.get("attributes")
-        if "project_property" in data_dict:
-            del data_dict["project_property"]
-        if "active" in data_dict:
-            del data_dict["active"]
-        if "created_time" in data_dict:
-            del data_dict["created_time"]
-        if "creator" in data_dict:
-            del data_dict["creator"]
-        if "organisation" in data_dict:
-            del data_dict["organisation"]
-        if "last_modified" in data_dict:
-            data_dict["last_modified"] = data_dict["last_modified"].split(".")[0]
-        if "status" in data_dict:
-            if data_dict["status"] == 1:
-                data_dict["status"] = "active"
-            else:
-                data_dict["status"] = "archived"
+        data_dict = data.get("_source")
+        # Extracting necessary fields
+        modified_data = {
+            "id": data_dict.get("id"),
+            "name": data_dict.get("name", ""),
+            "status": "active" if data_dict.get("status") == 1 else "archived",
+            "description": data_dict.get("description", ""),
+            "last_modified": datetime.fromtimestamp(
+                data_dict.get("modified_date", 0)
+            ).strftime("%Y-%m-%d %H:%M:%S"),
+            "tag_names": data_dict.get("tags", []),
+            "favourite": False,
+            "watch": False,
+        }
+
+        # Extract permissions
+        permissions = data_dict.get("permissions")
+        if permissions:
+            modified_data["watch"] = permissions[0].get("watch", False)
+            modified_data["favourite"] = permissions[0].get("is_bookmarked", False)
+
+        return modified_data
 
     @Track.track_decorator
     def list_contents(self, workspace_id: str):
         """
         This function fetches contents of a workspace from Polly.
 
-        ``Args:``
-            |  ``workspace_id :`` workspace id for the target workspace.
+        Args:
+            workspace_id : workspace id for the target workspace.
 
-        ``Returns:``
-            |  it will return a table with attributes.
-
-
-        .. code::
-
-
-                # create a obj
-                workspaces = Workspaces(token)
-                # from there you can other methods
-                workspaces.list_contents(workspace_id)
+        Returns:
+            Table: it will return a table with attributes.
         """
-        url = f"{self.base_url}/projects/{workspace_id}/files"
-        response = self.session.get(url)
-        error_handler(response)
+        url = f"{self.resource_url}/{workspace_id}/_search"
+        from_index = 0
+        fixed_size = 20
         details_list = []
-        data = response.json()["data"]
-        columns = ["file_name", "size", "last_modified"]
-        for i in data:
-            entry_list = []
-            file_name = i.get("attributes").get(columns[0])
-            size = i.get("attributes").get(columns[1])
-            last_modified = i.get("attributes").get(columns[2])
-            entry_list.append(file_name)
-            entry_list.append(size)
-            entry_list.append(last_modified)
-            details_list.append(entry_list)
-        df = pd.DataFrame(details_list, columns=columns)
+        response_columns = ["file_name", "size", "last_modified"]
+        while True:
+            payload = {
+                "from": from_index,
+                "size": fixed_size,
+                "query": {
+                    "bool": {
+                        "should": [
+                            {
+                                "bool": {
+                                    "must": [
+                                        {
+                                            "term": {
+                                                "_index": {"value": "{document_index}"}
+                                            }
+                                        },
+                                        {
+                                            "term": {
+                                                "workspace_id": {"value": workspace_id}
+                                            }
+                                        },
+                                        {
+                                            "term": {
+                                                "parent_id": {"value": workspace_id}
+                                            }
+                                        },
+                                    ]
+                                }
+                            },
+                            {
+                                "bool": {
+                                    "must": [
+                                        {
+                                            "term": {
+                                                "_index": {"value": "{workspace_index}"}
+                                            }
+                                        },
+                                        {
+                                            "nested": {
+                                                "path": "permissions",
+                                                "query": {
+                                                    "match": {
+                                                        "permissions.user_id": {
+                                                            "query": "{user_id}"
+                                                        }
+                                                    }
+                                                },
+                                            }
+                                        },
+                                    ]
+                                }
+                            },
+                        ]
+                    }
+                },
+            }
+            response = self.session.post(url, data=json.dumps(payload))
+            error_handler(response)
+            total_hits = response.json()["hits"]["total"]["value"]
+            data = response.json()["hits"]["hits"]
+            columns = ["entity_name", "size", "modified_date"]
+            for i in data:
+                file_name = i.get("_source").get(columns[0])
+                size = i.get("_source").get(
+                    columns[1], "-"
+                )  # If size is not present, set to "-"
+
+                # Convert size
+                if size != "-":
+                    size = self.convert_size(size)
+
+                last_modified = i.get("_source").get(columns[2])
+                if last_modified is None:
+                    last_modified = "-"
+                else:
+                    dt_object = datetime.fromtimestamp(last_modified)
+                    formatted_date = dt_object.strftime("%Y-%m-%d %H:%M:%S")
+                    last_modified = formatted_date
+
+                details_list.append([file_name, size, last_modified])
+
+            from_index += fixed_size
+            if from_index >= total_hits:
+                break
+        df = pd.DataFrame(details_list, columns=response_columns)
         return df
 
+    def convert_size(self, size_bytes):
+        if size_bytes == 0:
+            return "0B"
+        size_name = ("B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB")
+        i = int(math.floor(math.log(size_bytes, 1024)))
+        p = math.pow(1024, i)
+        s = round(size_bytes / p, 2)
+        return "%s %s" % (s, size_name[i])
+
     @Track.track_decorator
     def create_copy(
         self, source_id: int, source_path: str, destination_id: int, destination_path=""
     ) -> None:
         """
         Function to create a copy of files/folders existing in a workspace into another workspace.
+
         Args:
               source_id (int): workspace id of the source workspace where the file/folder exists
-              source_path (str) : file/folder path on the source workspace to be copied
-              destination_id (int) : workspace id of the destination workspace where the file/folder is to be copied
-              destination_path (str, optional) : optional parameter to specify the destination path
+              source_path (str): file/folder path on the source workspace to be copied
+              destination_id (int): workspace id of the destination workspace where the file/folder is to be copied
+              destination_path (str, optional): optional parameter to specify the destination path
 
         Raises:
               InvalidParameterException: when the parameter like source id is invalid
@@ -218,7 +317,7 @@ initialize a object that can use all function and methods of Workspaces class.
             raise InvalidParameterException("source_path")
         url = f"{self.base_url}/projects/{destination_id}/files/{destination_path}"
         source_key = f"{source_id}/{source_path}"
-        params = {"source": "workspace"}
+        params = {"source": "workspace", "source_workspace_id": source_id}
         sts_url = f"{self.base_url}/projects/{source_id}/credentials/files"
         creds = self.session.get(sts_url)
         error_handler(creds)
@@ -237,8 +336,9 @@ initialize a object that can use all function and methods of Workspaces class.
         url = f"{self.base_url}{links.get('self')}"
         while True:
             response = self.session.get(url)
-            error_handler(response)
-            status = response.json().get("data").get("status")
+            if response.json().get("errors"):
+                error_handler(response)
+            status = response.json()["primary_data"].get("status")
             if status != "INITIATED":
                 break
         print("Copy Operation Successful!")
@@ -249,11 +349,12 @@ initialize a object that can use all function and methods of Workspaces class.
     ) -> None:
         """
         Function to upload files/folders to workspaces.
+
         Args:
-              workspace_id (int) : id of the workspace where file need to uploaded
-              workspace_path (str) : path where the file/folder is to be uploaded.
+              workspace_id (int): id of the workspace where file need to uploaded
+              workspace_path (str): path where the file/folder is to be uploaded. \
               The workspace path should be prefixed with "polly://". Creates the folder if provided folder path doesn't exist.
-              local_path (str) : uploaded file/folder path
+              local_path (str): uploaded file/folder path
 
         Raises:
               InvalidParameterException: when the parameter like workspace id is invalid
@@ -294,16 +395,19 @@ initialize a object that can use all function and methods of Workspaces class.
         """
         Function to download files/folders from workspaces.
         A message will be displayed on the status of the operation.
+
         Args:
-              workspace_id (int) : Id of the workspace where file needs to uploaded
-              workspace_path (str) : Downloaded file on workspace. The workspace path should be prefixed with "polly://"
-              copy_workspace_path (bool) : Flag indicating whether the workspace path needs to copied in the working directory
+              workspace_id (int): Id of the workspace where file needs to uploaded
+              workspace_path (str): Downloaded file on workspace. The workspace path should be prefixed with "polly://"
+              copy_workspace_path (bool): Flag indicating whether the workspace path needs to copied in the working directory
+
         Returns:
               None
+
         Raises:
-              InvalidPathException : Invalid file path provided
-              OperationFailedException : Failed download
-              InvalidParameterException : Invalid parameter passed
+              InvalidPathException: Invalid file path provided
+              OperationFailedException: Failed download
+              InvalidParameterException: Invalid parameter passed
         """
         if not (workspace_id and isinstance(workspace_id, int)):
             raise InvalidParameterException("workspace_id")
@@ -330,12 +434,13 @@ initialize a object that can use all function and methods of Workspaces class.
     def sync_data(self, workspace_id: int, source_path: str, destination_path: str):
         """
         Function to sync directory to or from workspaces and local.
+
         Args:
-              workspace_id (int) : id of the workspace which is used for sync
-              source_path (str) : path for the directory that is to be used for sync.
+              workspace_id (int): id of the workspace which is used for sync
+              source_path (str): path for the directory that is to be used for sync. \
               Can be local path or a workspace path. The workspace path should be prefixed with "polly://".
-              destination_path (str) : path for the directory that is to be used for sync.
-              Can be local path or a workspace path.
+              destination_path (str): path for the directory that is to be used for sync. \
+              Can be local path or a workspace path. \
               The workspace path should be prefixed with "polly://".Creates the folder if provided folder path doesn't exist.
 
         Raises:
